@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 from .transformer import Transformer
-from sklearn.externals.joblib import Parallel, delayed
+from joblib import Parallel, delayed
 from ..techniques.technique import PositionVariantTechnique
 from .detection import detectBoxes
 
@@ -23,4 +23,4 @@ class TransformerForImageStackDetection(Transformer):
 
         newlistImages = Parallel(n_jobs=-1)(
             delayed(self.technique.apply)(image) for image in listImages if image is not None)
-        return [newlistImages,newBoxes]
\ No newline at end of file
+        return [newlistImages,newBoxes]
